@@ -27,7 +27,7 @@ module GirFFI
         info = super
         return info if info
         signal_id = GObject.signal_lookup signal_name, target_gtype
-        return UnintrospectableSignalInfo.new(signal_id) if signal_id > 0
+        return UnintrospectableSignalInfo.new(signal_id) unless signal_id.zero?
       end
     end
   end
