@@ -9,9 +9,7 @@ module GirFFI
 
     def setup_and_call(method, arguments, &block)
       method_name = setup_method method.to_s
-      unless method_name
-        raise NoMethodError, "undefined method `#{method}' for #{self}"
-      end
+      raise NoMethodError, "undefined method `#{method}' for #{self}" unless method_name
       send method_name, *arguments, &block
     end
 
