@@ -3,13 +3,13 @@
 require 'gir_ffi_test_helper'
 
 describe GirFFI::InfoExt::IUnresolvedInfo do
-  let(:klass) do
+  let(:info_class) do
     Class.new do
       include GirFFI::InfoExt::IUnresolvedInfo
     end
   end
 
-  let(:unresolved_info) { klass.new }
+  let(:unresolved_info) { info_class.new }
 
   describe '#to_ffi_type' do
     it 'returns the most generic type' do
